Learn R Programming

utr.annotation (version 1.0.4)

checkIfGainOrLoseAfterAlt: Check if the number of uAUG, ployA signal, or Kozak in UTR changes after alt

Description

checkIfGainOrLoseAfterAlt check if the number of uAUG, ployA signal, or Kozak in UTR changes after alt. This function only works to compare two "numeric" columns

Usage

checkIfGainOrLoseAfterAlt(variantsTable, colNameBeforeAlt, colNameAfterAlt)

Arguments

variantsTable

variantsTable: variants table

colNameBeforeAlt

the name of the column before alter, type of a string

colNameAfterAlt

the name of the column after alter, type of a string

Value

A list containing whether the number gained, lost, or equal after alter. If colNameBeforeAlt or colNameAfterAlt does not exist in the variantsTable, return NA