Learn R Programming

utr.annotation (version 1.0.4)

checkIfGainOrLoseAfterAltOneVariant: Check if the number of uAUG, ployA signal, or Kozak in UTR changes after alt for one variant

Description

checkIfGainOrLoseAfterAlt check if the number of uAUG, ployA signal, or Kozak in UTR changes after alt. This function only works to compare two "numeric" columns

Usage

checkIfGainOrLoseAfterAltOneVariant(variant, colNameBeforeAlt, colNameAfterAlt)

Arguments

variant

variant info

colNameBeforeAlt

the name of the column before alter, type of a string

colNameAfterAlt

the name of the column after alter, type of a string

Value

whether the number gained, lost, or equal after alter. If colNameBeforeAlt or colNameAfterAlt does not exist in the variantsTable, return NA