Learn R Programming

utr.annotation (version 1.0.4)

getKozakScore: Calculate the Kozak score for each Kozak sequence, and concatenate the numbers with ",".

Description

Calculate the Kozak score for each Kozak sequence, and concatenate the numbers with ",".

Usage

getKozakScore(variantsTable, kozakSeqs, kozakPWM)

Arguments

variantsTable

variants table

kozakSeqs

the column name of the kozak sequences

kozakPWM

Kozak PWM output from consensusMatrix() and PWM()

Value

a list containing scores for the kozak sequences. Can be used to add new column to the variants table.