Get the Kozak sequence in TSS region for transcripts in transcriptIdColumn.
getTSSKozak(variantsTable, utr5SeqTable, codingSeqTable, transcriptIdColumn)variants table
5' UTR sequence table from Ensembl DB. Have two columns: ensembl_transcript_id and seq
coding sequence table from Ensembl DB. Have two columns: ensembl_transcript_id and seq
the name of the transcript id column for the codon region
A list containing TSS Kozak sequences (NA if the transcript id in that row is NA). If transcriptIdColumn does not exist in the variantsTable, return NA