Learn R Programming

utr.annotation (version 1.0.4)

getTSSKozakOneVariant: Get the Kozak sequence in TSS region for transcripts in transcriptIdColumn for one variant.

Description

Get the Kozak sequence in TSS region for transcripts in transcriptIdColumn for one variant.

Usage

getTSSKozakOneVariant(
  variant,
  utr5SeqTable,
  codingSeqTable,
  transcriptIdColumn
)

Arguments

utr5SeqTable

5' UTR sequence table from Ensembl DB. Have two columns: ensembl_transcript_id and seq

codingSeqTable

coding sequence table from Ensembl DB. Have two columns: ensembl_transcript_id and seq

transcriptIdColumn

the name of the transcript id column for the codon region

variantsTable

variants table

Value

A string concatenated TSS Kozak sequences (NA if the transcript id in that row is NA)