Learn R Programming

utr.annotation (version 1.0.4)

get_conservation_scores: Get conservation scores for variants

Description

Get conservation scores for variants

Usage

get_conservation_scores(variantsTable, conservationBwPath)

Arguments

variantsTable

A variant table, positions are 1-based

conservationBwPath

The path of the bigWig conservation track file download from UCSC Genome Browser

Value

A vector of strings, which are conservation scores of input variants. If a variant reference sequence has more than 1 nucleotide, the conservation scores of all its positions will be concatenated with ";".