checkIfGainOrLoseAfterAlt check if the number of uAUG, ployA signal, or Kozak in UTR changes after alt. This function only works to compare two "numeric" columns
checkIfGainOrLoseAfterAltOneVariant(variant, colNameBeforeAlt, colNameAfterAlt)variant info
the name of the column before alter, type of a string
the name of the column after alter, type of a string
whether the number gained, lost, or equal after alter. If colNameBeforeAlt or colNameAfterAlt does not exist in the variantsTable, return NA