Get the Kozak sequence in TSS region for transcripts in transcriptIdColumn for one variant.
getTSSKozakOneVariant(
variant,
utr5SeqTable,
codingSeqTable,
transcriptIdColumn
)5' UTR sequence table from Ensembl DB. Have two columns: ensembl_transcript_id and seq
coding sequence table from Ensembl DB. Have two columns: ensembl_transcript_id and seq
the name of the transcript id column for the codon region
variants table
A string concatenated TSS Kozak sequences (NA if the transcript id in that row is NA)