Get conservation scores for variants
get_conservation_scores(variantsTable, conservationBwPath)A variant table, positions are 1-based
The path of the bigWig conservation track file download from UCSC Genome Browser
A vector of strings, which are conservation scores of input variants. If a variant reference sequence has more than 1 nucleotide, the conservation scores of all its positions will be concatenated with ";".